hierarchyResolved: Extract resolved leaf selections from a hierarchy input value

View source: R/hierarchyValue.R

hierarchyResolvedR Documentation

Extract resolved leaf selections from a hierarchy input value

Description

Extract resolved leaf selections from a hierarchy input value

Usage

hierarchyResolved(value)

Arguments

value

Value returned by a hierarchy input (input$...).

Value

A list of resolved node records, or an empty list.


shinyHierarchy documentation built on Oct. 2, 2026, 5:09 p.m.