View source: R/hierarchyValue.R
| hierarchyResolved | R Documentation |
Extract resolved leaf selections from a hierarchy input value
hierarchyResolved(value)
value |
Value returned by a hierarchy input ( |
A list of resolved node records, or an empty list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.